@@ -1,6 +1,8 @@
 {-# LANGUAGE DeriveDataTypeable #-}
 module Network.IRC.Bot.Log where
 
+import Data.ByteString (ByteString)
+import qualified Data.ByteString.Char8 as C
 import Data.Data
 
 data LogLevel
@@ -9,11 +11,11 @@ data LogLevel
     | Important
       deriving (Eq, Ord, Read, Show, Data, Typeable)
 
-type Logger = LogLevel -> String -> IO ()
+type Logger = LogLevel -> ByteString -> IO ()
 
 stdoutLogger :: LogLevel -> Logger
 stdoutLogger minLvl msgLvl msg
-    | msgLvl >= minLvl = putStrLn msg
+    | msgLvl >= minLvl = C.putStrLn msg -- assumes ascii, which is wrong(?)
     | otherwise        = return ()
 
 nullLogger :: Logger
